==> wicket-jquery-ui-core-7.3.0-sources.jar: com/googlecode/wicket/jquery/core/event/ISelectionChangedListener.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.googlecode.wicket.jquery.core.event;

import org.apache.wicket.ajax.AjaxRequestTarget;
import org.apache.wicket.util.io.IClusterable;

/**
 * Specifies that a widget handles a selection-changed AJAX behavior
 *
 * @author Sebastien Briquet - sebfz1
 */
public interface ISelectionChangedListener extends IClusterable
{
	/**
	 * Indicates whether the 'change' event is enabled.<br/>
	 * If true, the {@link #onSelectionChanged(AjaxRequestTarget)} event will be triggered<br/>
	 *
	 * @return false by default
	 */
	boolean isSelectionChangedEventEnabled();

	/**
	 * Triggers when the selection has changed
	 * 
	 * @param target the {@link AjaxRequestTarget}
	 */
	void onSelectionChanged(AjaxRequestTarget target);
}

==> wicket-jquery-ui-core-8.6.0-sources.jar: com/googlecode/wicket/jquery/core/event/ISelectionChangedListener.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.googlecode.wicket.jquery.core.event;

import org.apache.wicket.ajax.AjaxRequestTarget;
import org.apache.wicket.util.io.IClusterable;

/**
 * Specifies that a widget handles a selection-changed AJAX behavior
 *
 * @author Sebastien Briquet - sebfz1
 */
public interface ISelectionChangedListener extends IClusterable
{
	/**
	 * Indicates whether the 'change' event is enabled.<br>
	 * If true, the {@link #onSelectionChanged(AjaxRequestTarget)} event will be triggered<br>
	 *
	 * @return false by default
	 */
	boolean isSelectionChangedEventEnabled();

	/**
	 * Triggered when the selection has changed
	 * 
	 * @param target the {@link AjaxRequestTarget}
	 */
	void onSelectionChanged(AjaxRequestTarget target);
}
